# Installation of created package

pip install polygon-data-generator

# Get started
currency_pairs = [["AUD", "USD", [], portfolio("AUD", "USD")]] \
location = os.getcwd() \
print(location) \
data_writer(currency_pairs) #data_writer is replacing main function
